/**
  ******************************************************************************
  * @file           : main.h
  * @brief          : Header for main.c file.
  *                   This file contains the common defines of the application.
  ******************************************************************************
  */

// Define to prevent recursive inclusion -------------------------------------
#ifndef __MAIN_H__
#define __MAIN_H__

// Includes ------------------------------------------------------------------

/* USER CODE BEGIN Includes */

/* USER CODE END Includes */

// Private define ------------------------------------------------------------
#define DEBOUNCE_TIME 10

#define Sw4_Pin GPIO_PIN_13
#define Sw4_GPIO_Port GPIOC
#define Sw6_Pin GPIO_PIN_14
#define Sw6_GPIO_Port GPIOC
#define Sw3_Pin GPIO_PIN_15
#define Sw3_GPIO_Port GPIOC
#define Enc1B_Pin GPIO_PIN_0
#define Enc1B_GPIO_Port GPIOA
#define Enc2B_Pin GPIO_PIN_1
#define Enc2B_GPIO_Port GPIOA
#define Enc3B_Pin GPIO_PIN_2
#define Enc3B_GPIO_Port GPIOA
#define Enc4B_Pin GPIO_PIN_3
#define Enc4B_GPIO_Port GPIOA
#define Enc1A_Pin GPIO_PIN_0
#define Enc1A_GPIO_Port GPIOB
#define Enc2A_Pin GPIO_PIN_1
#define Enc2A_GPIO_Port GPIOB
#define Enc3A_Pin GPIO_PIN_2
#define Enc3A_GPIO_Port GPIOB
#define Sw1_Pin GPIO_PIN_10
#define Sw1_GPIO_Port GPIOB
#define Sw2_Pin GPIO_PIN_11
#define Sw2_GPIO_Port GPIOB
#define POT_CS_Pin GPIO_PIN_12
#define POT_CS_GPIO_Port GPIOB
#define POT_SCK_Pin GPIO_PIN_13
#define POT_SCK_GPIO_Port GPIOB
#define VolumeMode_Pin GPIO_PIN_14
#define VolumeMode_GPIO_Port GPIOB
#define POT_SI_Pin GPIO_PIN_15
#define POT_SI_GPIO_Port GPIOB
#define Srf_Int_Pin GPIO_PIN_9
#define Srf_Int_GPIO_Port GPIOA
#define Enc5B_Pin GPIO_PIN_10
#define Enc5B_GPIO_Port GPIOA
#define Sw5_Pin GPIO_PIN_11
#define Sw5_GPIO_Port GPIOA
#define Sw7_Pin GPIO_PIN_12
#define Sw7_GPIO_Port GPIOA
#define SWDIO_Pin GPIO_PIN_13
#define SWDIO_GPIO_Port GPIOA
#define SWCLK_Pin GPIO_PIN_14
#define SWCLK_GPIO_Port GPIOA
#define LED_Pin GPIO_PIN_15
#define LED_GPIO_Port GPIOA
#define Enc4A_Pin GPIO_PIN_3
#define Enc4A_GPIO_Port GPIOB
#define Enc5A_Pin GPIO_PIN_4
#define Enc5A_GPIO_Port GPIOB
#define SwE1_Pin GPIO_PIN_5
#define SwE1_GPIO_Port GPIOB
#define SwE2_Pin GPIO_PIN_6
#define SwE2_GPIO_Port GPIOB
#define SwE3_Pin GPIO_PIN_7
#define SwE3_GPIO_Port GPIOB
#define SwE4_Pin GPIO_PIN_8
#define SwE4_GPIO_Port GPIOB
#define SwE5_Pin GPIO_PIN_9
#define SwE5_GPIO_Port GPIOB

// ########################## Assert Selection ##############################
/**
  * @brief Uncomment the line below to expanse the "assert_param" macro in the
  *        HAL drivers code
  */
/* #define USE_FULL_ASSERT    1U */

/* USER CODE BEGIN Private defines */
typedef unsigned char u8;
typedef unsigned short u16;
typedef unsigned long u32;

typedef enum
{
  false, true
} bool;

#define enableInterrupts()   __set_PRIMASK(0);
#define disableInterrupts()  __set_PRIMASK(1);
#define pinSet(Port,Pin)     Port->BSRR = (Pin)
#define pinReset(Port,Pin)   Port->BSRR = (uint32_t)(Pin) << 16U
#define pinToggle(Port,Pin)  Port->ODR ^= (Pin)
#define pinRead(Port,Pin)    !!(Port->IDR & (Pin))

#define VOLUME_STEPS 30

typedef enum
{
  SRF_NOP, GET_FW_VERSION, READ_SRF_CLEAR, ENC5_DATA, ENC5_VOLUME,
  SET_MAX_VOLUMES_CH1, SET_MAX_VOLUMES_CH2, SET_VOLUME_STEPS,
} SrfCommands;

typedef struct __attribute__ ( ( packed ) )
{
  int           enc1:4, enc2:4, enc3:4, enc4:4, enc5:4;
  int           swe1:1, swe2:1, swe3:1, swe4:1, swe5:1;
  int           sw1:1, sw2:1, sw3:1, sw4:1, sw5:1, sw6:1, sw7:1;
} Surface;

typedef struct __attribute__ ( ( packed ) )
{
  unsigned int  encoders:20;
  unsigned int  switches:12;
} Surface_bits;

typedef struct __attribute__ ( ( packed ) )
{
  unsigned int  day:5;
  unsigned int  month:4;
  unsigned int  year:11;
  unsigned int  channels:2;
  unsigned int  amplifier:1;
} FwVersion;

typedef struct __attribute__ ( ( packed ) )
{
  u16           command;
  u16           param;
} SrfCommand;

typedef struct __attribute__ ( ( packed ) )
{
  u8            L1, R1, L2, R2;
} Volume;

struct __attribute__ ( ( packed ) ) SavedOptions
{
  u16           id;
  u8            volume_steps;
  u8            volume_last;
};

#define FLASH_ERASE_TIMEOUT	  ((uint32_t)5000)	// 5s

#define SO_SIZE ( ( sizeof( struct SavedOptions ) + 3 ) & ~3 )

extern u8     __EEPROM_segment_start__;
extern u8     __EEPROM_segment_end__;
extern u8     __EEPROM_segment_size__;
extern struct SavedOptions LocalOptions;

/* USER CODE END Private defines */

#ifdef __cplusplus
 extern "C" {
#endif
void _Error_Handler(char *, int);

#define Error_Handler() _Error_Handler(__FILE__, __LINE__)
#ifdef __cplusplus
}
#endif

#endif /* __MAIN_H__ */

